Index: include/effects/SkBlurMaskFilter.h |
diff --git a/include/effects/SkBlurMaskFilter.h b/include/effects/SkBlurMaskFilter.h |
index 3ba91774f05b459f4afec83ccf09b438456b235e..89eff72290c5e5508e2da921982a8b7f63195045 100644 |
--- a/include/effects/SkBlurMaskFilter.h |
+++ b/include/effects/SkBlurMaskFilter.h |
@@ -32,13 +32,20 @@ public: |
}; |
/** Create a blur maskfilter. |
* @param style The SkBlurStyle to use |
* @param sigma Standard deviation of the Gaussian blur to apply. Must be > 0. |
* @param flags Flags to use - defaults to none |
* @return The new blur maskfilter |
*/ |
static sk_sp<SkMaskFilter> Make(SkBlurStyle style, SkScalar sigma, |
- uint32_t flags = kNone_BlurFlag); |
+ const SkRect& occluder, uint32_t flags = kNone_BlurFlag); |
+ |
+ static sk_sp<SkMaskFilter> Make(SkBlurStyle style, SkScalar sigma, |
+ uint32_t flags = kNone_BlurFlag) { |
+ return Make(style, sigma, SkRect::MakeEmpty(), flags); |
+ } |
/** Create an emboss maskfilter |
@param blurSigma standard deviation of the Gaussian blur to apply |
@@ -32,13 +32,20 @@ public: |
}; |
/** Create a blur maskfilter. |
- * @param style The SkBlurStyle to use |
- * @param sigma Standard deviation of the Gaussian blur to apply. Must be > 0. |
- * @param flags Flags to use - defaults to none |
+ * @param style The SkBlurStyle to use |
+ * @param sigma Standard deviation of the Gaussian blur to apply. Must be > 0. |
+ * @param occluder The rect for which no pixels need be drawn (b.c. it will be overdrawn |
+ * with some opaque object |
+ * @param flags Flags to use - defaults to none |
* @return The new blur maskfilter |
*/ |